Crate feather_macros

Crate feather_macros 

Attribute Macros

middleware_fn
This macro defines a middleware function that can be used in Feather applications.
It allows you to write middleware functions without repeating the type signatures for request, response, and context. Example: