Crate feather_macros
feather_
macros
0.2.0
All Items
Crate Items
Attribute Macros
Crate
feather_
macros
Attribute Macros

middleware_
fn
This macro defines a middleware function that can be used in Feather applications.
It allows you to write middleware functions without repeating the type signatures for request, response, and context. Example: